from typing import List, Optional

from .invoice_item import InvoiceItemResponse
from ..base_model import BaseResponseModel


class FeeResponse(BaseResponseModel):
    lago_id: Optional[str]
    item: Optional[InvoiceItemResponse]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    vat_amount_cents: Optional[int]
    vat_amount_currency: Optional[str]
    total_amount_cents: Optional[int]
    total_amount_currency: Optional[str]
    units: Optional[float]
    events_count: Optional[int]


class FeesResponse(BaseResponseModel):
    __root__: List[FeeResponse]



from .applied_add_on import AppliedAddOn
from .applied_coupon import AppliedCoupon
from .billable_metric import BillableMetric, BillableMetricGroup
from .charge import Charge, Charges, ChargesResponse
from .coupon import Coupon, LimitationConfiguration
from .credit import CreditResponse, CreditsResponse
from .credit_note import Item, Items, CreditNote, CreditNoteUpdate
from .plan import Plan
from .add_on import AddOn
from .organization import Organization, OrganizationBillingConfiguration
from .event import Event, BatchEvent
from .customer import Customer, CustomerBillingConfiguration, Metadata, MetadataList
from .invoice import InvoicePaymentStatusChange, Invoice, InvoiceMetadata, InvoiceMetadataList
from .invoice_item import InvoiceItemResponse
from .subscription import Subscription
from .customer_usage import Metric, ChargeObject, ChargeUsage, CustomerUsageResponse
from .wallet import Wallet
from .wallet_transaction import WalletTransaction
